pub struct HandlebarsHandler(/* private fields */);Expand description
A trillium handler that provides registered templates to downsequence handlers
Implementations
Sourceimpl HandlebarsHandler
impl HandlebarsHandler
Sourcepub fn new(source: impl Into<Self>) -> Self
pub fn new(source: impl Into<Self>) -> Self
Builds a new trillium Handlebars handler from either a directory
glob string or PathBuf or a
handlebars::Handlebars<'static>
instance
From a glob
use trillium_handlebars::{HandlebarsConnExt, HandlebarsHandler};
use trillium_testing::TestServer;
let handler = (
HandlebarsHandler::new("**/*.hbs"),
|mut conn: trillium::Conn| async move {
conn.assign("name", "handlebars")
.render("examples/templates/hello.hbs")
},
);
let app = TestServer::new(handler).await;
app.get("/")
.await
.assert_ok()
.assert_body("hello handlebars!");From a handlebars::Handlebars
use trillium_handlebars::{HandlebarsHandler, Handlebars, HandlebarsConnExt};
use trillium_testing::TestServer;
// building a Handlebars directly
let mut handlebars = Handlebars::new();
handlebars.register_template_string("greet-user", "Hello {{name}}")?;
let handler = (
HandlebarsHandler::new(handlebars),
|mut conn: trillium::Conn| async move {
conn.assign("name", "handlebars")
.render("greet-user")
}
);
let app = TestServer::new(handler).await;
app.get("/")
.await
.assert_ok()
.assert_body("Hello handlebars");Trait Implementations
Sourceimpl Clone for HandlebarsHandler
impl Clone for HandlebarsHandler
Sourcefn clone(&self) -> HandlebarsHandler
fn clone(&self) -> HandlebarsHandler
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HandlebarsHandler
impl Debug for HandlebarsHandler
Sourceimpl Default for HandlebarsHandler
impl Default for HandlebarsHandler
Sourcefn default() -> HandlebarsHandler
fn default() -> HandlebarsHandler
Returns the “default value” for a type. Read more
Sourceimpl From<&str> for HandlebarsHandler
impl From<&str> for HandlebarsHandler
Sourceimpl From<Registry<'static>> for HandlebarsHandler
impl From<Registry<'static>> for HandlebarsHandler
Sourcefn from(ah: Handlebars<'static>) -> Self
fn from(ah: Handlebars<'static>) -> Self
Converts to this type from the input type.
Sourceimpl From<PathBuf> for HandlebarsHandler
impl From<PathBuf> for HandlebarsHandler
Sourceimpl Handler for HandlebarsHandler
impl Handler for HandlebarsHandler
Sourceasync fn run(&self, conn: Conn) -> Conn
async fn run(&self, conn: Conn) -> Conn
Executes this handler, performing any modifications to the Conn that are desired.
Sourcefn init(&mut self, info: &mut Info) -> impl Future<Output = ()> + Send
fn init(&mut self, info: &mut Info) -> impl Future<Output = ()> + Send
Performs one-time async set up on a mutable borrow of the Handler before the server starts
accepting requests. This allows a Handler to be defined in synchronous code but perform
async setup such as establishing a database connection or fetching some state from an
external source. This is optional, and chances are high that you do not need this. Read more
Sourcefn before_send(&self, conn: Conn) -> impl Future<Output = Conn> + Send
fn before_send(&self, conn: Conn) -> impl Future<Output = Conn> + Send
Performs any final modifications to this conn after all handlers have been run. Although
this is a slight deviation from the simple conn->conn->conn chain represented by most
Handlers, it provides an easy way for libraries to effectively inject a second handler into
a response chain. This is useful for loggers that need to record information both before and
after other handlers have run, as well as database transaction handlers and similar library
code. Read more
Sourcefn has_upgrade(&self, upgrade: &Upgrade) -> bool
fn has_upgrade(&self, upgrade: &Upgrade) -> bool
predicate function answering the question of whether this Handler would like to take
ownership of the negotiated Upgrade. If this returns true, you must implement
Handler::upgrade. The first handler that responds true to this will receive
ownership of the trillium::Upgrade in a subsequent call to
Handler::upgradeSourcefn upgrade(&self, upgrade: Upgrade) -> impl Future<Output = ()> + Send
fn upgrade(&self, upgrade: Upgrade) -> impl Future<Output = ()> + Send
This will only be called if the handler reponds true to
Handler::has_upgrade and will
only be called once for this upgrade. There is no return value, and this function takes
exclusive ownership of the underlying transport once this is called. You can downcast
the transport to whatever the source transport type is and perform any non-http protocol
communication that has been negotiated. You probably don’t want this unless you’re
implementing something like websockets. Please note that for many transports such as
TcpStreams, dropping the transport (and therefore the Upgrade) will hang up /
disconnect.Auto Trait Implementations
impl Freeze for HandlebarsHandler
impl RefUnwindSafe for HandlebarsHandler
impl Send for HandlebarsHandler
impl Sync for HandlebarsHandler
impl Unpin for HandlebarsHandler
impl UnsafeUnpin for HandlebarsHandler
impl UnwindSafe for HandlebarsHandler